@@ -10,13 +10,14 @@
 //!
 //! 1. chrono-english is not actively maintained: <https://github.com/stevedonovan/chrono-english/issues/22>
 //! 2. interim simplifies a lot of the code, removing a lot of potential panics and adds some optimisations.
-//! 3. supports `no_std`, as well as the `time` crate
+//! 3. supports `no_std`, as well as the `time` and `jiff` crates
 //!
 //! ## Features
 //!
 //! * `std`: This crate is `no_std` compatible. Disable the default-features to disable the std-lib features (just error reporting)
-//! * `time`: This crate is compatible with the [time crate](https://github.com/time-rs/time).
-//! * `chrono`: This crate is compatible with the [chrono crate](https://github.com/chronotope/chrono).
+//! * `time_0_3`: This crate is compatible with the [time crate](https://github.com/time-rs/time).
+//! * `chrono_0_4`: This crate is compatible with the [chrono crate](https://github.com/chronotope/chrono).
+//! * `jiff_0_1`: This crate is compatible with the [jiff crate](https://github.com/BurntSushi/jiff).
 //!
 //! ## Supported Formats
 //!
@@ -79,7 +80,7 @@
 //! assert_eq!(parse_duration("15m ago").unwrap(), Interval::Seconds(-15 * 60));
 //! ```
 #![cfg_attr(docsrs, feature(doc_cfg))]
-#![cfg_attr(not(feature = "std"), no_std)]
+#![no_std]
 #![warn(clippy::pedantic)]
 #![allow(
     clippy::if_not_else,
@@ -92,6 +93,12 @@
     clippy::cast_sign_loss
 )]
 
+#[cfg(test)]
+extern crate alloc;
+
+#[cfg(feature = "std")]
+extern crate std;
+
 /// A collection of traits to abstract over date-time implementations
 pub mod datetime;
 mod errors;
@@ -171,9 +178,13 @@ pub fn parse_duration(s: &str) -> DateResult<Interval> {
 
 #[cfg(test)]
 mod tests {
-    use crate::{parse_duration, DateError, Dialect, Interval};
+    #![allow(unused_imports)]
 
-    #[cfg(feature = "chrono")]
+    use crate::{parse_duration, DateError, Dialect, Interval};
+    use alloc::string::String;
+    use alloc::string::ToString;
+
+    #[cfg(feature = "chrono_0_4")]
     #[track_caller]
     fn format_chrono(d: &crate::types::DateTimeSpec, dialect: Dialect) -> String {
         use chrono::{FixedOffset, TimeZone};
@@ -189,7 +200,7 @@ mod tests {
         }
     }
 
-    #[cfg(feature = "time")]
+    #[cfg(feature = "time_0_3")]
     #[track_caller]
     fn format_time(d: &crate::types::DateTimeSpec, dialect: Dialect) -> String {
         use time::{Date, Month, PrimitiveDateTime, Time, UtcOffset};
@@ -211,6 +222,50 @@ mod tests {
         }
     }
 
+    #[cfg(feature = "jiff_0_1")]
+    #[track_caller]
+    fn format_jiff_0_1(d: &crate::types::DateTimeSpec, dialect: Dialect) -> String {
+        use jiff_0_1::{
+            civil::Date, civil::DateTime, civil::Time, tz::Offset, tz::TimeZone, Zoned,
+        };
+        let tz = TimeZone::fixed(Offset::from_seconds(7200).unwrap());
+        let base = DateTime::from_parts(Date::constant(2018, 3, 21), Time::constant(11, 00, 00, 0));
+        let base = tz.to_zoned(base).unwrap();
+        match crate::into_date_string(d.clone(), base, dialect) {
+            Err(e) => {
+                panic!("unexpected error attempting to format [time] {d:?}\n\t{e:?}")
+            }
+            Ok(date) => {
+                // let format = time::format_description::parse(
+                //     "[year]-[month]-[day]T[hour]:[minute]:[second][offset_hour sign:mandatory]:[offset_minute]",
+                // ).unwrap();
+                date.strftime("%FT%T%:z").to_string()
+            }
+        }
+    }
+
+    #[cfg(feature = "jiff_0_2")]
+    #[track_caller]
+    fn format_jiff_0_2(d: &crate::types::DateTimeSpec, dialect: Dialect) -> String {
+        use jiff_0_2::{
+            civil::Date, civil::DateTime, civil::Time, tz::Offset, tz::TimeZone, Zoned,
+        };
+        let tz = TimeZone::fixed(Offset::from_seconds(7200).unwrap());
+        let base = DateTime::from_parts(Date::constant(2018, 3, 21), Time::constant(11, 00, 00, 0));
+        let base = tz.to_zoned(base).unwrap();
+        match crate::into_date_string(d.clone(), base, dialect) {
+            Err(e) => {
+                panic!("unexpected error attempting to format [time] {d:?}\n\t{e:?}")
+            }
+            Ok(date) => {
+                // let format = time::format_description::parse(
+                //     "[year]-[month]-[day]T[hour]:[minute]:[second][offset_hour sign:mandatory]:[offset_minute]",
+                // ).unwrap();
+                date.strftime("%FT%T%:z").to_string()
+            }
+        }
+    }
+
     macro_rules! assert_date_string {
         ($s:literal, $dialect:ident, $expect:literal) => {
             let dialect = Dialect::$dialect;
@@ -221,20 +276,36 @@ mod tests {
                 }
                 Ok(date) => date,
             };
-            #[cfg(feature = "chrono")]
+            #[cfg(feature = "chrono_0_4")]
             {
                 let output = format_chrono(&_date, dialect);
                 let expected: &str = $expect;
                 if output != expected {
-                    panic!("unexpected output attempting to format [chrono] {input:?}.\nexpected: {expected:?}\n  parsed: {_date:?}");
+                    panic!("unexpected output attempting to format [chrono] {input:?}.\nexpected: {expected:?}\n  parsed: {_date:?} [{output:?}]");
                 }
             }
-            #[cfg(feature = "time")]
+            #[cfg(feature = "time_0_3")]
             {
                 let output = format_time(&_date, dialect);
                 let expected: &str = $expect;
                 if output != expected {
-                    panic!("unexpected output attempting to format [time] {input:?}.\nexpected: {expected:?}\n  parsed: {_date:?}");
+                    panic!("unexpected output attempting to format [time] {input:?}.\nexpected: {expected:?}\n  parsed: {_date:?} [{output:?}]");
+                }
+            }
+            #[cfg(feature = "jiff_0_1")]
+            {
+                let output = format_jiff_0_1(&_date, dialect);
+                let expected: &str = $expect;
+                if output != expected {
+                    panic!("unexpected output attempting to format [jiff] {input:?}.\nexpected: {expected:?}\n  parsed: {_date:?} [{output:?}]");
+                }
+            }
+            #[cfg(feature = "jiff_0_2")]
+            {
+                let output = format_jiff_0_2(&_date, dialect);
+                let expected: &str = $expect;
+                if output != expected {
+                    panic!("unexpected output attempting to format [jiff] {input:?}.\nexpected: {expected:?}\n  parsed: {_date:?} [{output:?}]");
                 }
             }
         };
@@ -248,6 +319,8 @@ mod tests {
         assert_date_string!("friday 8pm", Uk, "2018-03-23T20:00:00+02:00");
         assert_date_string!("12am", Uk, "2018-03-21T00:00:00+02:00");
         assert_date_string!("12pm", Uk, "2018-03-21T12:00:00+02:00");
+        assert_date_string!("7:26 AM", Uk, "2018-03-21T07:26:00+02:00");
+        assert_date_string!("7:26 PM", Uk, "2018-03-21T19:26:00+02:00");
 
         // The day of week is the _next_ day after today, so "Tuesday" is the next Tuesday after Wednesday
         assert_date_string!("tues", Uk, "2018-03-27T00:00:00+02:00");
@@ -258,6 +331,10 @@ mod tests {
         // but otherwise it means the day in the next week..
         assert_date_string!("next mon", Uk, "2018-04-02T00:00:00+02:00");
 
+        assert_date_string!("last year", Uk, "2017-03-21T00:00:00+02:00");
+        assert_date_string!("this year", Uk, "2018-03-21T00:00:00+02:00");
+        assert_date_string!("next year", Uk, "2019-03-21T00:00:00+02:00");
+
         assert_date_string!("last fri 9.30", Uk, "2018-03-16T09:30:00+02:00");
 
         // date expressed as month, day - relative to today. May have a time part
@@ -324,6 +401,11 @@ mod tests {
             };
         }
 
+        assert_duration!("1 seconds", Interval::Seconds(1));
+        assert_duration!("24 seconds", Interval::Seconds(24));
+        assert_duration!("34 s", Interval::Seconds(34));
+        assert_duration!("34 sec", Interval::Seconds(34));
+
         assert_duration!("6h", Interval::Seconds(6 * 3600));
         assert_duration!("4 hours ago", Interval::Seconds(-4 * 3600));
         assert_duration!("5 min", Interval::Seconds(5 * 60));
@@ -345,7 +427,48 @@ mod tests {
         assert_duration_err!("tuesday", DateError::UnexpectedDate);
         assert_duration_err!(
             "bananas",
-            DateError::ExpectedToken("week day or month name", 0..7)
+            DateError::ExpectedToken("unsupported identifier", 0..7)
+        );
+    }
+
+    #[cfg(feature = "chrono_0_4")]
+    #[test]
+    /// <https://github.com/conradludgate/interim/issues/12>
+    fn regression_12_chrono() {
+        use chrono::TimeZone;
+
+        let now: chrono::DateTime<_> = chrono_tz::America::Los_Angeles
+            .with_ymd_and_hms(2024, 1, 1, 12, 00, 00)
+            .unwrap();
+        let without_timezone =
+            crate::parse_date_string("2024-06-01 12:00:00", now, Dialect::Us).unwrap();
+        let with_timezone =
+            crate::parse_date_string("2024-06-01 12:00:00 -07:00", now, Dialect::Us).unwrap();
+
+        assert_eq!(without_timezone, with_timezone);
+        assert_eq!(with_timezone.to_string(), "2024-06-01 12:00:00 PDT");
+    }
+
+    #[cfg(feature = "jiff_0_1")]
+    #[test]
+    fn regression_12_jiff() {
+        use jiff_0_1::{
+            civil::Date, civil::DateTime, civil::Time, tz::Offset, tz::TimeZone, Zoned,
+        };
+
+        let tz = TimeZone::get("America/Los_Angeles").unwrap();
+        let base = DateTime::from_parts(Date::constant(2024, 1, 1), Time::constant(12, 00, 00, 0));
+        let now = tz.to_zoned(base).unwrap();
+
+        let without_timezone =
+            crate::parse_date_string("2024-06-01 12:00:00", now.clone(), Dialect::Us).unwrap();
+        let with_timezone =
+            crate::parse_date_string("2024-06-01 12:00:00 -07:00", now, Dialect::Us).unwrap();
+
+        assert_eq!(without_timezone, with_timezone);
+        assert_eq!(
+            with_timezone.to_string(),
+            "2024-06-01T12:00:00-07:00[America/Los_Angeles]"
         );
     }
 }
